==> hinemos_src-3.0.5.tar.gz: Hinemos_src-3.0.5/PerformanceEJB/src/com/clustercontrol/performance/operator/InvPercentageOfTotal.java <==
/*
                                                                                                                                                                 
Copyright (C) 2008 NTT DATA Corporation
                                                                                                                                                                 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.
                                                                                                                                                                 
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
                                                                                                                                                                 
*/

package com.clustercontrol.performance.operator;

/**
 * 1番目の要素以外の差分値が全体の差分値に占める割合を計算します。
 */
public class InvPercentageOfTotal extends SnmpOperator {
	@Override
	public double calc() throws CollectedDataNotFoundException, InvalidValueException{
		double perfData;
		
		double targetDiff = getDifferenceValue("var0");
		double diffTotal = getDifferenceValueTotal();

		// 分母が0の場合（更新されていない場合）
		if(diffTotal == 0){
			return Double.NaN;
		}

//		// 分子の値が更新されていない場合100%となることの対処
//		if(targetDiff == 0){
//			return Double.NaN;
//		}
		
		perfData = (double)targetDiff / diffTotal * 100.0D;
		
		return 100.0D - perfData;
	}
}

==> hinemos_src-3.1.5.tar.gz: Hinemos_src-3.1.5/PerformanceEJB/src/com/clustercontrol/performance/operator/InvPercentageOfTotal.java <==
/*
                                                                                                                                                                 
Copyright (C) 2008 NTT DATA Corporation
                                                                                                                                                                 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License
as published by the Free Software Foundation, version 2.
                                                                                                                                                                 
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
                                                                                                                                                                 
*/

package com.clustercontrol.performance.operator;

/**
 * 1番目の要素以外の差分値が全体の差分値に占める割合を計算します。
 */
public class InvPercentageOfTotal extends Operator {
	@Override
	public double calc() throws CollectedDataNotFoundException, InvalidValueException{
		double perfData;
		
		double targetDiff = getDifferenceValue("var0");
		double diffTotal = getDifferenceValueTotal();

		// 分母が0の場合（更新されていない場合）
		if(diffTotal == 0){
			return Double.NaN;
		}

//		// 分子の値が更新されていない場合100%となることの対処
//		if(targetDiff == 0){
//			return Double.NaN;
//		}
		
		perfData = (double)targetDiff / diffTotal * 100.0D;
		
		return 100.0D - perfData;
	}
}
